@@ -1,3 +1,4 @@
+#include "wrap_helpers.hpp"
 #include <isl/ctx.h>
 #include <isl/space.h>
 #include <isl/set.h>
@@ -22,7 +23,6 @@
 #include <stdexcept>
 #include <boost/python.hpp>
 #include <boost/unordered_map.hpp>
-#include "wrap_helpers.hpp"
 
 // TODO: flow.h
 // TODO: better error reporting
@@ -198,15 +198,21 @@ namespace isl
   WRAP_CLASS(union_pw_qpolynomial_fold);
   WRAP_CLASS(term);
 
-  WRAP_CLASS(id_list);
-  WRAP_CLASS(basic_set_list);
-  WRAP_CLASS(set_list);
+  // matches order in isl_declaration_macros.h
+  WRAP_CLASS(val_list);
   WRAP_CLASS(aff_list);
   WRAP_CLASS(pw_aff_list);
-  WRAP_CLASS(band_list);
   WRAP_CLASS(ast_expr_list);
   WRAP_CLASS(ast_node_list);
 
+  WRAP_CLASS(id_list);
+  WRAP_CLASS(band_list);
+  WRAP_CLASS(constraint_list);
+
+  WRAP_CLASS(basic_set_list);
+  WRAP_CLASS(set_list);
+  // end match
+
   WRAP_CLASS(id_to_ast_expr);
 
   WRAP_CLASS(band);
